@@ -8,7 +8,7 @@ use Scalar::Util ();
 package Hydrogen;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.013';
+our $VERSION   = '0.014';
 
 use Exporter::Shiny qw( croak fc );
 
@@ -69,6 +69,18 @@ Normal version of the function:
     say $hash{Alice};                ## ==> 123
     say hhr_get( \%hash, 'Bob' );    ## ==> 456
 
+Autoboxing, kinda:
+
+    use feature 'say';
+    use Hydrogen::HashRef ();
+    
+    my $hashref = {};
+    $hashref->Hydrogen::HashRef::set( Alice => 123 );
+    $hashref->Hydrogen::HashRef::set( Bob   => 456 );
+    
+    say $hashref->{Alice};                            ## ==> 123
+    say $hashref->Hydrogen::HashRef::get( 'Bob' );    ## ==> 456
+
 Version of the function which uses prototypes:
 
     use feature 'say';
@@ -117,9 +129,16 @@ Perl. And I mean I<really> simple things.
 Things which are often Perl builtin functions, operators, and even just
 part of Perl syntax like accessing keys within hashes.
 
-What is the point in having functions to do these simple things? Well, you
-can make a coderef pointing to C<< \&Hydrogen::Number::add >> but you can't
-make a coderef pointing to Perl's C<< += >> operator!
+=head1 RATIONALE
+
+Whydrogen?
+
+You can make a coderef pointing to C<< \&Hydrogen::Number::add >> but you
+can't make a coderef pointing to Perl's C<< += >> operator!
+
+If you are implementing a scripting language or DSL which needs to provide
+a standard library of builtin functions, then Hydrogen may be a good place
+to start.
 
 =head1 THE HYDROGEN LIBRARY
 
